asm

package
v0.0.0-...-6576c52 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 22, 2026 License: BSD-3-Clause, MIT Imports: 0 Imported by: 0

Documentation

Index

Constants

const (
	// Reserve ensures that the allocated register for this constraint is not shared with other constraints.
	Reserve clobber = "&"
)

Variables

This section is empty.

Functions

func Clobber

func Clobber(Register) constraint

Clobber ensures that the specified register is not used by any of the constraints.

func In

func In(...any) constraint

In specifies that the constraint is an input constraint.

func InOut

func InOut(...any) constraint

InOut specifies that the constraint is both an input and output constraint.

func Inline

func Inline(asm string, constraints ...constraint)

Inline emits an inline assembler expression into the current code block.

func Out

func Out(...any) constraint

Out specifies that the constraint is an output constraint.

Types

type Alias

type Alias string

Alias declares an alias for a constraint in the assembly code block.

type Register

type Register string

Register describes a register constraint.

type RegisterClass

type RegisterClass string

RegisterClass describes a register class constraint.

Directories

Path Synopsis

Jump to