Documentation
¶
Index ¶
Constants ¶
const (
// Reserve ensures that the allocated register for this constraint is not shared with other constraints.
Reserve clobber = "&"
)
Variables ¶
This section is empty.
Functions ¶
func Clobber ¶
func Clobber(Register) constraint
Clobber ensures that the specified register is not used by any of the constraints.
func InOut ¶
func InOut(...any) constraint
InOut specifies that the constraint is both an input and output constraint.
Types ¶
Click to show internal directories.
Click to hide internal directories.